@@ -26,7 +26,7 @@ def makes(ivar2):
     #print("Creating OS folders in need! This may take a few seconds or minutes!")
     #os.system('git clone https://github.com/WWEMGamer2/OS-Folders.git')
     i = input('[./OS/config.py] Where is your mandatory folder? ')
-    for f in os.listdir(f'./{ivar2}'):
+    for f in os.listdir(f'./'):
         if i == f:
             print("Found the required folder.")
             print("Formatting...")
@@ -34,7 +34,7 @@ def makes(ivar2):
         else: 
             print("Found no folder under the name specified.")
             if input('Would you like to create it? (y,n) ') == "y":
-                os.mkdir(f'./OS/{i}')
+                os.mkdir(f'./{ivar2}/{i}')
     
     print(f"[!] The process was completed. You can now remove the make() function from {__name__}.py")
 
